@@ -1,16 +1,15 @@
 # -*- coding: UTF-8 -*-
-"""The `OERPLib` module defines the :class:`OERP` class.
+"""The `oerplib` module defines the :class:`OERP` class.
 
 The :class:`OERP` class manage the client-side operations which are related to
 an `OpenERP` server. You can use this one to write Python programs that performs
 a variety of automated jobs that communicate with an `OpenERP` server.
-
 """
 
 __author__ = 'ABF Osiell - Sebastien Alix'
 __email__ = 'sebastien.alix@osiell.com'
 __licence__ = 'LGPL v3'
-__version__ = '0.6.0'
+__version__ = '0.7.1'
 
 from oerplib.oerp import OERP
 from oerplib import error
